Curve

Struct Curve 

pub struct Curve(pub [f64; 6]);
A bezier curve.

For an absolute, command "C x1 y1 x2 y2 x y"

Or, for a relative command "c dx1 dy1 dx2 dy2 dx, dy"

The point [x y] specifies where the curve should end.

The points [x1 y1] and [x2 y2] are the control points. The former being for controlling the start of the curve and the latter controlling the end.

Tuple Fields

0: [f64; 6]

Implementations

Source

impl Curve

pub fn smooth_bezier_by_args<'a>( prev: &'a Position, item: &'a Position, ) -> Option<Self>

Returns a curve based on a bezier commands

pub fn is_convex(&self) -> bool

Returns whether a curve is convex

A curve is convex when the middle of the curve’s line is below the curve’s midpoint

pub fn is_arc(&self, circle: &Circle, make_arcs: &MakeArcs, error: f64) -> bool

Returns whether a curve is an arc of a circle

pub fn is_arc_prev( &self, circle: &Circle, make_arcs: &MakeArcs, error: f64, ) -> bool

Returns whether a curve from a previous command is an arc of a circle

pub fn is_straight(&self, error: f64) -> bool

Returns whether the arc fits on a straight line

pub fn is_data_straight(args: &[f64], error: f64) -> bool

Returns whether the arc fits on a straight line

pub fn find_arc_angle(&self, rel_circle: &Circle) -> f64

Returns the angle from the start of an arc to the end