pub struct Path(pub Vec<Position>);Expand description
Equivalent of a Path, with positional information
Tuple Fields
0: Vec<Position>Implementations
Sourceimpl Path
impl Path
Sourcepub fn split_mut(
path: &mut [Option<Position>],
index: usize,
) -> Option<(&'_ mut Position, &'_ mut Option<Position>, &'_ mut [Option<Position>])>
pub fn split_mut( path: &mut [Option<Position>], index: usize, ) -> Option<(&'_ mut Position, &'_ mut Option<Position>, &'_ mut [Option<Position>])>
Split by [...prev_paths, prev, item, ...next_paths]
Returns
When the list is of some length, item isn’t first, and item is Some
ⓘ
Some(
// None, if at index 0; otherwise, Some(&mut Option<Position>)
prev,
// &mut Some(Position), An item, whose value can be set to None
item,
// The rest of the items ahead
next_paths,
)Otherwise, None